;;; custom-load.el --- automatically extracted custom dependencies

;;; Code:

(custom-add-loads 'mail '("eudc"))
(custom-add-loads 'comm '("eudc-ldap" "eudc-ph" "eudc"))
(custom-add-loads 'eudc-ldap '("eudc-ldap"))
(custom-add-loads 'eudc '("eudc"))
(custom-add-loads 'eudc-ph '("eudc-ph"))

;;; custom-load.el ends here
